library angular2_material.src.components.checkbox.checkbox;

import "package:angular2/angular2.dart" show Component, View, Attribute;
import "package:angular2/src/facade/lang.dart" show isPresent;
import "package:angular2_material/src/core/constants.dart" show KEY_SPACE;
import "package:angular2/src/facade/browser.dart" show KeyboardEvent;
import "package:angular2/src/facade/lang.dart" show NumberWrapper;

@Component(
    selector: "md-checkbox",
    properties: const ["checked", "disabled"],
    host: const {
  "(keydown)": "onKeydown(\$event)",
  "[tabindex]": "tabindex",
  "[attr.role]": "\"checkbox\"",
  "[attr.aria-checked]": "checked",
  "[attr.aria-disabled]": "disabled"
})
@View(
    templateUrl: "angular2_material/src/components/checkbox/checkbox.html",
    directives: const [])
class MdCheckbox {
  /** Whether this checkbox is checked. */
  bool checked;
  /** Whether this checkbox is disabled. */
  bool _disabled;
  /** Setter for tabindex */
  num tabindex;
  MdCheckbox(@Attribute("tabindex") String tabindex) {
    this.checked = false;
    this.tabindex =
        isPresent(tabindex) ? NumberWrapper.parseInt(tabindex, 10) : 0;
    this._disabled = false;
  }
  get disabled {
    return this._disabled;
  }
  set disabled(value) {
    this._disabled = isPresent(value) && !identical(value, false);
  }
  onKeydown(KeyboardEvent event) {
    if (event.keyCode == KEY_SPACE) {
      event.preventDefault();
      this.toggle(event);
    }
  }
  toggle(event) {
    if (this.disabled) {
      event.stopPropagation();
      return;
    }
    this.checked = !this.checked;
  }
}
